# Hardware Notes

Some thoughts and suggestions about Lollipop hardware options.

## Official Boards

After much testing, discussion, success, failure, and inspiration... we are happy to announce the boards we will officially support!

We've selected different boards as our primary targets for the Lollipop Cloud project. Our team members will be working with these boards heavily and will prioritize supporting them. The boards were selected for their price ($25-$100 USD), specifications, and ease-of-use, keeping in mind our goal of making self-hosted clouds an accessible reality.

### Raspberry Pi 3b and 3b+

The [Raspberry Pi 3b and 3b+](http://raspberrypi.org/) are arm64v8 boards. They have 1Gb RAM, 4 core CPU, lots of expansion options and more.

The ```Rasbian``` distribution is setup to run as arm32v7 so be mindful when reading documentation. Ubuntu offers a 64bit release that's arm64v8.

This is our recommended board for deploying a Lollipop Cloud, especially for our beginner users.

### Orange Pi PC 2

The [Orange Pi PC 2](http://www.orangepi.org/orangepipc2/) is a reasonably priced arm64v8 board. This board can be purchased as a full set that includes a board, case, and power supply. It's got enough RAM, CPU, and more to run a full self-hosted cloud for an individual, family, and maybe a little more.

It has 3 USB ports for additional WiFi adapters or USB disks. It also has a full HDMI connector so you can setup using a USB keyboard and TV/monitor/etc.

It does *not* have a WiFi chip on-board, be sure to remember a WiFi dongle if needed.

### Orange Pi Plus 2e

The [Orange Pi Plus 2e](http://www.orangepi.org/orangepiplus2e/) is an arm32v7 board. It packs 2Gb of RAM, 4 core CPU, lots of expansion options, built-in WiFi, built-in ethernet, and more.

This board can run a self-hosted cloud for an individual, family, or small group. If you're looking for the "big board," this is it.

## Storage Boards

Due to our community asking for boards that support large amounts of storage we've found and tested the following setups for more storage focused Lollipop Cloud builds. The below builds are "bill of materials" that outline our tested and working configurations.

### Nano Pi Neo2 + NAS Board

- [Nano Pi Neo2](https://www.friendlyarm.com/index.php?route=product/product&path=69&product_id=180)
  - Select ```1Gb RAM``` model
- [Nano Pi Neo2 NAS Kit](https://www.friendlyarm.com/index.php?route=product/product&path=89_93&product_id=222)
- [Noctua 5V 60mm fan (NF-A6x25 5V PWM)](https://noctua.at/en/products/fan/nf-a6x25-5v-pwm)
- 12v 5.5-2.1mm barrel jack power supply capable of providing at least 3A of power
- 2.5" sata disk

#### Notes

- The 60mm fan can be mounted directly above the main board components at the back of the case by cutting a 55mm square hole in the top of the case as well as drilling 4 holes for securing the fan to the case.
- If you don't need/want the metal case you can select the ```Heatsink``` and ```1-bay NAS dock``` options on the main Nano Pi Neo2 product page and run it without a case
- If running the build without a case the [Noctua 5v 40mm fans (NF-A4x10 5V PWM)](https://noctua.at/en/products/fan/nf-a4x10-5v-pwm) fits perfectly on top of the Neo2 heatsink and will provide enough airflow to keep the build from overheating
- ZFS works well on this board if focused on bulk storage, samba (windows file sharing) and/or nfs
- The **ENTIRE** amount of usb, disk and network speed **COMBINED** will total between 50 and 75 M/s. The disk is attached to the usb controller which also seems to influence network io speeds in our tests. This will *not* be fast but it will act as (and feel like) a very capable USB2 disk running services attached to your network.

### Nano Pi M4 + SATA Hat

- [Nano Pi M4 + Heat Sink + SATA Hat](https://www.friendlyarm.com/index.php?route=product/product&path=69&product_id=234)
  - Select either RAM option, 4Gb is better if your budget allows
  - Select ```Heat Sink``` (this is NOT optional as the board WILL overheat without the heatsink)
  - Select ```4x SATA HAT```
- [Noctua 5v 40mm fans (NF-A4x10 5V PWM)](https://noctua.at/en/products/fan/nf-a4x10-5v-pwm)
- [Noctua 5V 60mm fan (NF-A6x25 5V PWM)](https://noctua.at/en/products/fan/nf-a6x25-5v-pwm)
- Sata power splitter(s) so you can power the desired number of disks *and* the 2 four pin fans listed above
- 12V 5.5-2.1mm barrel jack power supply capable of providing at least 5A of power (8A max)
- Sata Disks


#### Notes

- Attach the 40mm Noctua fan to the SATA Hat heat sink, it gets very warm when under load and can easily become thermal throttled
- Attach the 60mm Noctua fan upright at the front of the main board + heatsink. The main board gets over 80C under load without active cooling is and is prone to thermal shutdown events
- There is no case that we've been able to find, this is a "naked build"
- Sata power splitters and sata -> pwm fan adapters can be used to provide >2 sata power ports for disks attached to the hat and powered by the hat
- Consider a 40mm or 60mm fan for cooling disks, you can double stick tape the disks together (use mutiple layers to allow about 2-5mm space between disks) and then mount a fan to the front of the disks to keep them cool
- ZFS runs in a *default* configuration on this setup, you do *not* need the module tuning in our documentation for this deployment. However, if using the 2Gb RAM model, using the 3rd tuning option from our documentation (the one with the most RAM usage) can help reduce zfs RAM usage and allow more services to be setup

## Expansion Options

### USB Storage

If you're going to run services like NextCloud, Syncthing and/or Samba you will want to consider what kind of USB disk to use. I'd recommend a [Sandisk Cruzer Fit (link)](https://www.sandisk.com/home/usb-flash/cruzer-fit) or [Sandisk Ultra Fit (link)](https://www.sandisk.com/home/usb-flash/ultra-fit) or similar, low power flash drive. Full hard disks that aren't SSD's tend to be power hungry and can cause problems with SBCs.

### WiFi

- The author has had decent luck with the [ASUS USB-N13](https://www.asus.com/us/Networking/USB-N13/) adapter in client mode. Be minful of your 2.4ghz channel setup. If this adapter and your AP share a channel in 2.4ghz this adapter *will* drop packets and/or suffer disconnections
  - Sometimes a reboot is necessary to get authentication to work properly after initial setup
  - The author has **NOT** tested AP mode
- The author has had very good luck with the [ASUS USB-N53](https://www.asus.com/us/Networking/USBN53/) in AP mode. *Both* 2.4ghz and 5ghz can used for AP mode at the same time.
  - The author has **NOT** tested client mode
- The author has had decent luck with the TP-Link N150 USB WiFi adapter in client mode
- The author could not get the TP-Link N300 USB WiFi adapter to work in client mode

### WiFi Antennas

- [https://www.mouser.com/ProductDetail/?qs=%2fv8iy7V9uiwj65CKT%2f%252b6tQ%3d%3d](https://www.mouser.com/ProductDetail/?qs=%2fv8iy7V9uiwj65CKT%2f%252b6tQ%3d%3d)
- [https://www.mouser.com/ProductDetail/?qs=G9o9YCnxvoZVoyw0A06Ktg%3d%3d](https://www.mouser.com/ProductDetail/?qs=G9o9YCnxvoZVoyw0A06Ktg%3d%3d)
- [https://www.mouser.com/ProductDetail/?qs=WUa1z%2fNV9%252b2lzv2ZS%2f50GQ%3d%3d](https://www.mouser.com/ProductDetail/?qs=WUa1z%2fNV9%252b2lzv2ZS%2f50GQ%3d%3d)
- [https://www.mouser.com/ProductDetail/?qs=RuW%2fu%252bNMQmv6yDroBT8RNQ%3d%3d](https://www.mouser.com/ProductDetail/?qs=RuW%2fu%252bNMQmv6yDroBT8RNQ%3d%3d)
- [https://www.mouser.com/ProductDetail/Antenova/SR4W030-100?qs=sGAEpiMZZMuBTKBKvsBmlN73K%2f2BcYXln6YUd9YVZ3FLX3OerI69PA%3d%3d](https://www.mouser.com/ProductDetail/Antenova/SR4W030-100?qs=sGAEpiMZZMuBTKBKvsBmlN73K%2f2BcYXln6YUd9YVZ3FLX3OerI69PA%3d%3d)
- [https://www.mouser.com/ProductDetail/Antenova/SRF2W021-100?qs=sGAEpiMZZMuBTKBKvsBmlMeP1Lut7uca61hspfdOxQexT8ZJsKeXqw%3d%3d](https://www.mouser.com/ProductDetail/Antenova/SRF2W021-100?qs=sGAEpiMZZMuBTKBKvsBmlMeP1Lut7uca61hspfdOxQexT8ZJsKeXqw%3d%3d)

### Power / LiPo Batteries

- [SparkFun mosfet power control (link)](https://www.sparkfun.com/products/12959)
- [Pimoroni On/Off shim (link)](https://www.adafruit.com/product/3581)
- [SparkFun Charger/Booster (link)](https://learn.sparkfun.com/tutorials/sparkfun-5v1a-lipo-chargerbooster-hookup-guide)
- [Power Meter](https://www.sparkfun.com/products/14331)
- [Pimoroni LiPo shim (link)](https://www.adafruit.com/product/3196)

### Storage

- [Ableconn mSATA Hat (link)](https://www.amazon.com/dp/B00WQJ8BH2)
- [Ableconn nvme Hat (link)](https://www.amazon.com/dp/B01LZ0LCTU)

### Displays

- [Waveshare 4.2 inch e-ink display (link)](https://www.waveshare.com/product/modules/oleds-lcds/e-paper/4.2inch-e-paper-module.htm?___SID=U)
- [Waveshare 2.9 inch e-ink display (link)](https://www.waveshare.com/product/modules/oleds-lcds/e-paper/2.9inch-e-paper-module.htm?___SID=U)
- [Pimoroni e-ink hat (link)](https://www.adafruit.com/product/3743)

### Input

- [Waveshare touch keypad (link)](https://www.waveshare.com/product/RPi-Touch-Keypad.htm)
- [Pimoroni touch button hat (link)](https://www.adafruit.com/product/3472)
- [Pimoroni push button shim (link)](https://www.adafruit.com/product/3582)
- [Adafruit display+button hat (link)](https://www.adafruit.com/product/3531)
- [Adafruit joystick+button hat (link)](https://www.adafruit.com/product/3464)
- [Pimoroni display+button hat (link)](https://www.adafruit.com/product/2694)

### Cell Data

- [LTE rPi Shield (link)](http://sixfab.com/product/raspberry-pi-3g-4glte-base-shield-v2/)
- [LTE/4G pciE (link)](http://sixfab.com/product/quectel-ec25-mini-pcle-4glte-module/)
- [3G pciE (link)](http://sixfab.com/product/quectel-uc20-mini-pcle-3g-module/)

### Misc

- [SparkFun TTL serial usb adapter (link)](https://www.sparkfun.com/products/14050)
- [Adafruit TTL serial usb adapter (link)](https://www.adafruit.com/product/3309)
- [SparkFun Bluetooth Mate Silver (link)](https://www.sparkfun.com/products/12576)
- [Adafruit GPS (link)](https://www.adafruit.com/product/746)
- [Pimoroni mini hat extender (link)](https://www.adafruit.com/product/3182)
- [Pimoroni hat extender (link)](https://www.adafruit.com/product/3742)

### 3d Printed Cases

- Pine64 [(source)](https://www.thingiverse.com/thing:1831345) : ```3d_printer_sources/Pine_A64_Two-Parts_case.zip```
- Orange Pi Zero [Plus] Base [(source)](https://www.thingiverse.com/thing:2776831) : ```3d_printer_sources/Orange_Pi_Zero_-_Minimal_Mount.zip```
- Orange Pi Zero [Plus] Case [(source)](https://www.thingiverse.com/thing:1939780) : ```3d_printer_sources/Orange_Pi_Zero_Case.zip```
- Orange Pi Zero [Plus] + Expansion Board Case [(source)](https://www.thingiverse.com/thing:2353879) : ```3d_printer_sources/Orange_Pi_Zero_+_Expansion_Board_Case.zip```
- Orange Pi Zero [Plus] + NAS Board Case [(source)](https://www.thingiverse.com/thing:2122451) : ```3d_printer_sources/Orange_Pi_Zero_NAS_Board_Case.zip```
- Orange Pi PC Case (External Mounts) [(source)](https://www.thingiverse.com/thing:2239240) : ```3d_printer_sources/Orange_PI_PC_Case_with_External_mounts_+_M5_mount.zip```
- Orange Pi PC NAS Case [(source)](https://www.thingiverse.com/thing:2468854) : ```3d_printer_sources/Orange_PI_PC_NAS_Case.zip```
- Orange Pi One Case [(source)](https://www.thingiverse.com/thing:1447933) : ```3d_printer_sources/OrangePi_One_Case.zip```
- Orange Pi One NAS Case [(source)](https://www.thingiverse.com/thing:2790266) : ```3d_printer_sources/Orange_Pi_One_NAS_Case.zip```
- Orange Pi Zero NAS Case (minimal) [(source)](https://www.thingiverse.com/thing:2740032) : ```3d_printer_sources/Orange_Pi_Zero_NAS_minimal.zip```
- Orange Pi Zero 2+ H5 Case [(source)](https://www.thingiverse.com/thing:2797865) : ```3d_printer_sources/Orange_Pi_Zero_2+_H5_Case.zip```
- Orange Pi Zero 2 Case [(source)](https://www.thingiverse.com/thing:2626323) : ```3d_printer_sources/Orange_Pi_Zero_2_Case.zip```
- Orange Pi Plus 2E Case [(source)](https://www.thingiverse.com/thing:2251219) : ```3d_printer_sources/Orange_Pi_plus_2e_case.zip```
- Orange Pi Plus 2E Case (alt) [(source)](https://www.thingiverse.com/thing:1916113) : ```3d_printer_sources/Orange_Pi_Plus_2E_case_2.zip```
- Orange Pi Zero Plus2 H3 Case [(source)](https://www.thingiverse.com/thing:2802598) : ```3d_printer_sources/
